﻿namespace ExtSpec.Build
{
    using System.IO;
    using ExtSpec.Build.Wrappers;

    /// <summary>
    /// Provides file system services.
    /// </summary>
    public class FileSystemProvider : BuildServiceBase, IFileSystemProvider
    {
        private IFileSystemWrapper fileSystemWrapper;

        /// <summary>
        /// Initializes a new instance of the <see cref="FileSystemProvider" /> class.
        /// </summary>
        /// <param name="context">The context.</param>
        /// <param name="fileSystemWrapper">The file system wrapper.</param>
        public FileSystemProvider(IBuildContext context, IFileSystemWrapper fileSystemWrapper)
            : base(context)
        {
            this.fileSystemWrapper = fileSystemWrapper;
        }

        /// <summary>
        /// Resets the build path prior to building.
        /// </summary>
        public void ResetBuildPath()
        {
            if (this.fileSystemWrapper.DirectoryExists(this.Context.BuildPath))
            {
                this.fileSystemWrapper.EmptyDirectory(this.Context.BuildPath);
            }
            else
            {
                this.fileSystemWrapper.CreateDirectory(this.Context.BuildPath);
            }
        }

        /// <summary>
        /// Cleans up the build path.
        /// </summary>
        public void CleanupBuildPath()
        {
            this.fileSystemWrapper.DeleteFile(this.Context.OutputFilePath);
            this.fileSystemWrapper.DeleteFile(this.Context.TypeScriptDefinitionFilePath);
        }

        /// <summary>
        /// Rebuilds the example library directory.
        /// </summary>
        public void RebuildExampleLibrary()
        {
            var path = Path.Combine(this.Context.ExamplePath, DirectoryName.Library);

            if (this.fileSystemWrapper.DirectoryExists(path))
            {
                this.fileSystemWrapper.DeleteDirectory(path, true);
            }

            this.fileSystemWrapper.CopyDirectory(this.Context.LibraryPath, path);
        }

        /// <summary>
        /// Writes the output to the examples directory.
        /// </summary>
        public void CopyOutputToExamples()
        {
            var path = Path.Combine(this.Context.ExamplePath, DirectoryName.Library, this.Context.Name.ToLower());

            if (!this.fileSystemWrapper.DirectoryExists(path))
            {
                this.fileSystemWrapper.CreateDirectory(path);
            }

            this.fileSystemWrapper.CopyFile(this.Context.OutputFilePath, Path.Combine(path, Path.GetFileName(this.Context.OutputFilePath)), true);
        }
    }
}
