﻿namespace ExtSpec.Build
{
    /// <summary>
    /// Contains the context used to build the library.
    /// </summary>
    public interface IBuildContext
    {
        /// <summary>
        /// Gets the short name of the library.
        /// </summary>
        /// <value>
        /// The name.
        /// </value>
        string Name { get; }

        /// <summary>
        /// Gets the title of the library.
        /// </summary>
        /// <value>
        /// The title.
        /// </value>
        string Title { get; }

        /// <summary>
        /// Gets the version of the library.
        /// </summary>
        /// <value>
        /// The version.
        /// </value>
        string Version { get; }

        /// <summary>
        /// Gets the copyright statement of the library.
        /// </summary>
        /// <value>
        /// The copyright.
        /// </value>
        string Copyright { get; }

        /// <summary>
        /// Gets the root directory path.
        /// </summary>
        /// <value>
        /// The root path.
        /// </value>
        string RootPath { get; }

        /// <summary>
        /// Gets the build directory path.
        /// </summary>
        /// <value>
        /// The build path.
        /// </value>
        string BuildPath { get; }

        /// <summary>
        /// Gets the example directory path.
        /// </summary>
        /// <value>
        /// The example path.
        /// </value>
        string ExamplePath { get; }

        /// <summary>
        /// Gets the library directory path.
        /// </summary>
        /// <value>
        /// The library path.
        /// </value>
        string LibraryPath { get; }

        /// <summary>
        /// Gets the main zip file path.
        /// </summary>
        /// <value>
        /// The main zip file path.
        /// </value>
        string MainZipFilePath { get; }

        /// <summary>
        /// Gets the example zip file path.
        /// </summary>
        /// <value>
        /// The example zip file path.
        /// </value>
        string ExampleZipFilePath { get; }

        /// <summary>
        /// Gets the output file path.
        /// </summary>
        /// <value>
        /// The output file path.
        /// </value>
        string OutputFilePath { get; }

        /// <summary>
        /// Gets the type script definition file path.
        /// </summary>
        /// <value>
        /// The type script definition file path.
        /// </value>
        string TypeScriptDefinitionFilePath { get; }

        /// <summary>
        /// Gets the license file path.
        /// </summary>
        /// <value>
        /// The license file path.
        /// </value>
        string LicenseFilePath { get; }
    }
}
