﻿namespace ExtSpec.Build
{
    using System;
    using System.Diagnostics;

    /// <summary>
    /// Provides process execution services.
    /// </summary>
    public class ProcessProvider : IProcessProvider
    {
        /// <summary>
        /// Executes the specified exe path.
        /// </summary>
        /// <param name="exePath">The exe path.</param>
        /// <param name="arguments">The arguments.</param>
        /// <returns>
        /// A Tuple containing an exit code and output.
        /// </returns>
        public Tuple<int, string> Execute(string exePath, string arguments)
        {
            string standardOutput;
            int exitCode;

            using (var process = new Process())
            {
                process.StartInfo.UseShellExecute = false;
                process.StartInfo.RedirectStandardOutput = true;
                process.StartInfo.CreateNoWindow = true;
                process.StartInfo.FileName = exePath;
                process.StartInfo.Arguments = arguments;
                process.Start();

                standardOutput = process.StandardOutput.ReadToEnd();

                process.WaitForExit();

                exitCode = process.ExitCode;
            }

            return new Tuple<int, string>(exitCode, standardOutput);
        }
    }
}
