﻿#pragma warning disable 1591

namespace ExtSpec.Build.Wrappers
{
    using System;
    using System.Collections;
    using System.Collections.Generic;
    using System.IO;
    using System.Text;
    using Ionic.Zip;
    using Ionic.Zlib;

    public interface IZipFile : IDisposable
    {
        event EventHandler<AddProgressEventArgs> AddProgress;

        event EventHandler<ExtractProgressEventArgs> ExtractProgress;

        event EventHandler<ReadProgressEventArgs> ReadProgress;

        event EventHandler<SaveProgressEventArgs> SaveProgress;

        event EventHandler<ZipErrorEventArgs> ZipError;

        bool AddDirectoryWillTraverseReparsePoints { get; set; }

        Encoding AlternateEncoding { get; set; }

        ZipOption AlternateEncodingUsage { get; set; }

        int BufferSize { get; set; }

        bool CaseSensitiveRetrieval { get; set; }

        int CodecBufferSize { get; set; }

        string Comment { get; set; }

        CompressionLevel CompressionLevel { get; set; }

        CompressionMethod CompressionMethod { get; set; }

        int Count { get; }

        bool EmitTimesInUnixFormatWhenSaving { get; set; }

        bool EmitTimesInWindowsFormatWhenSaving { get; set; }

        EncryptionAlgorithm Encryption { get; set; }

        ICollection<ZipEntry> Entries { get; }

        ICollection<ZipEntry> EntriesSorted { get; }

        ICollection<string> EntryFileNames { get; }

        ExtractExistingFileAction ExtractExistingFile { get; set; }

        bool FlattenFoldersOnExtract { get; set; }

        bool FullScan { get; set; }

        string Info { get; }

        bool? InputUsesZip64 { get; }

        int MaxOutputSegmentSize { get; set; }

        string Name { get; set; }

        int NumberOfSegmentsForMostRecentSave { get; }

        bool? OutputUsedZip64 { get; }

        int ParallelDeflateMaxBufferPairs { get; set; }

        long ParallelDeflateThreshold { get; set; }

        string Password { set; }

        bool? RequiresZip64 { get; }

        SetCompressionCallback SetCompression { get; set; }

        bool SortEntriesBeforeSaving { get; set; }

        TextWriter StatusMessageTextWriter { get; set; }

        CompressionStrategy Strategy { get; set; }

        string TempFileFolder { get; set; }

        Zip64Option UseZip64WhenSaving { get; set; }

        ZipErrorAction ZipErrorAction { get; set; }

        ZipEntry this[int ix] { get; }

        ZipEntry this[string fileName] { get; }

        ZipEntry AddDirectory(string directoryName);

        ZipEntry AddDirectory(string directoryName, string directoryPathInArchive);

        ZipEntry AddDirectoryByName(string directoryNameInArchive);

        ZipEntry AddEntry(string entryName, byte[] byteContent);

        ZipEntry AddEntry(string entryName, Stream stream);

        ZipEntry AddEntry(string entryName, string content);

        ZipEntry AddEntry(string entryName, WriteDelegate writer);

        ZipEntry AddEntry(string entryName, OpenDelegate opener, CloseDelegate closer);

        ZipEntry AddEntry(string entryName, string content, Encoding encoding);

        ZipEntry AddFile(string fileName);

        ZipEntry AddFile(string fileName, string directoryPathInArchive);

        void AddFiles(IEnumerable<string> fileNames);

        void AddFiles(IEnumerable<string> fileNames, string directoryPathInArchive);

        void AddFiles(IEnumerable<string> fileNames, bool preserveDirHierarchy, string directoryPathInArchive);

        ZipEntry AddItem(string fileOrDirectoryName);

        ZipEntry AddItem(string fileOrDirectoryName, string directoryPathInArchive);

        void AddSelectedFiles(string selectionCriteria);

        void AddSelectedFiles(string selectionCriteria, bool recurseDirectories);

        void AddSelectedFiles(string selectionCriteria, string directoryOnDisk);

        void AddSelectedFiles(string selectionCriteria, string directoryOnDisk, bool recurseDirectories);

        void AddSelectedFiles(string selectionCriteria, string directoryOnDisk, string directoryPathInArchive);

        void AddSelectedFiles(string selectionCriteria, string directoryOnDisk, string directoryPathInArchive, bool recurseDirectories);

        bool ContainsEntry(string name);

        void ExtractAll(string path);

        void ExtractAll(string path, ExtractExistingFileAction extractExistingFile);

        void ExtractSelectedEntries(string selectionCriteria);

        void ExtractSelectedEntries(string selectionCriteria, ExtractExistingFileAction extractExistingFile);

        void ExtractSelectedEntries(string selectionCriteria, string directoryPathInArchive);

        void ExtractSelectedEntries(string selectionCriteria, string directoryInArchive, string extractDirectory);

        void ExtractSelectedEntries(string selectionCriteria, string directoryPathInArchive, string extractDirectory, ExtractExistingFileAction extractExistingFile);

        IEnumerator<ZipEntry> GetEnumerator();

        IEnumerator GetNewEnum();

        void Initialize(string fileName);

        void RemoveEntries(ICollection<string> entriesToRemove);

        void RemoveEntries(ICollection<ZipEntry> entriesToRemove);

        void RemoveEntry(string fileName);

        void RemoveEntry(ZipEntry entry);

        int RemoveSelectedEntries(string selectionCriteria);

        int RemoveSelectedEntries(string selectionCriteria, string directoryPathInArchive);

        void Save();

        void Save(Stream outputStream);

        void Save(string fileName);

        void SaveSelfExtractor(string exeToGenerate, SelfExtractorFlavor flavor);

        void SaveSelfExtractor(string exeToGenerate, SelfExtractorSaveOptions options);

        ICollection<ZipEntry> SelectEntries(string selectionCriteria);

        ICollection<ZipEntry> SelectEntries(string selectionCriteria, string directoryPathInArchive);

        string ToString();

        ZipEntry UpdateDirectory(string directoryName);

        ZipEntry UpdateDirectory(string directoryName, string directoryPathInArchive);

        ZipEntry UpdateEntry(string entryName, byte[] byteContent);

        ZipEntry UpdateEntry(string entryName, Stream stream);

        ZipEntry UpdateEntry(string entryName, string content);

        ZipEntry UpdateEntry(string entryName, WriteDelegate writer);

        ZipEntry UpdateEntry(string entryName, OpenDelegate opener, CloseDelegate closer);

        ZipEntry UpdateEntry(string entryName, string content, Encoding encoding);

        ZipEntry UpdateFile(string fileName);

        ZipEntry UpdateFile(string fileName, string directoryPathInArchive);

        void UpdateFiles(IEnumerable<string> fileNames);

        void UpdateFiles(IEnumerable<string> fileNames, string directoryPathInArchive);

        void UpdateItem(string itemName);

        void UpdateItem(string itemName, string directoryPathInArchive);

        void UpdateSelectedFiles(string selectionCriteria, string directoryOnDisk, string directoryPathInArchive, bool recurseDirectories);
    }
}
