﻿namespace ExtSpec.Build.Wrappers
{
    using System.IO;
    using System.Xml.Serialization;

    /// <summary>
    /// Wraps an XML Serializer.
    /// </summary>
    public class XmlSerializationWrapper : IXmlSerializationWrapper
    {
        /// <summary>
        /// Deserializes the specified serialized string.
        /// </summary>
        /// <typeparam name="T">Any class.</typeparam>
        /// <param name="serialized">The serialized string.</param>
        /// <returns>
        /// An instance of T.
        /// </returns>
        public T Deserialize<T>(string serialized)
            where T : class
        {
            var serializer = new XmlSerializer(typeof(T));

            using (var reader = new StringReader(serialized))
            {
                return (T)serializer.Deserialize(reader);
            }
        }

        /// <summary>
        /// Serializes the specified input.
        /// </summary>
        /// <typeparam name="T">Any class.</typeparam>
        /// <param name="input">The input.</param>
        /// <returns>
        /// XML serialized version of the input.
        /// </returns>
        public string Serialize<T>(T input)
            where T : class
        {
            var serializer = new XmlSerializer(typeof(T));

            using (var writer = new StringWriter())
            {
                serializer.Serialize(writer, input);

                return writer.ToString();
            }
        }
    }
}
