﻿namespace ExtSpec.Build.Wrappers
{
    using System.IO;
    using System.Text;

    /// <summary>
    /// Factory for Zip Files.
    /// </summary>
    public class ZipFileFactory : IZipFileFactory
    {
        /// <summary>
        /// Creates a new <see cref="IZipFile" /> instance.
        /// </summary>
        /// <returns>A new <see cref="IZipFile" /> instance.</returns>
        public IZipFile Create()
        {
            return new ZipFile();
        }

        /// <summary>
        /// Creates a new <see cref="IZipFile" /> instance using the given encoding.
        /// </summary>
        /// <param name="encoding">The Encoding is used as the default alternate encoding for entries with
        /// filenames or comments that cannot be encoded with the IBM437 code page.</param>
        /// <returns>A new <see cref="IZipFile" /> instance.</returns>
        public IZipFile Create(Encoding encoding)
        {
            return new ZipFile(encoding);
        }

        /// <summary>
        /// Creates a new <see cref="IZipFile" /> instance using the given file name.
        /// </summary>
        /// <param name="fileName">The filename to use for the new zip archive.</param>
        /// <returns>A new <see cref="IZipFile" /> instance.</returns>
        public IZipFile Create(string fileName)
        {
            return new ZipFile(fileName);
        }

        /// <summary>
        /// Creates a new <see cref="IZipFile" /> instance using the given file name and encoding.
        /// </summary>
        /// <param name="fileName">The filename to use for the new zip archive.</param>
        /// <param name="encoding">The Encoding is used as the default alternate encoding for entries with
        /// filenames or comments that cannot be encoded with the IBM437 code page.</param>
        /// <returns>A new <see cref="IZipFile" /> instance.</returns>
        public IZipFile Create(string fileName, Encoding encoding)
        {
            return new ZipFile(fileName, encoding);
        }

        /// <summary>
        /// Creates a new <see cref="IZipFile" /> instance using the given file name and status message writer.
        /// </summary>
        /// <param name="fileName">The filename to use for the new zip archive.</param>
        /// <param name="statusMessageWriter">A TextWriter to use for writing
        /// verbose status messages.</param>
        /// <returns>A new <see cref="IZipFile" /> instance.</returns>
        public IZipFile Create(string fileName, TextWriter statusMessageWriter)
        {
            return new ZipFile(fileName, statusMessageWriter);
        }

        /// <summary>
        /// Creates a new <see cref="IZipFile" /> instance using the given file name, encoding and status message writer.
        /// </summary>
        /// <param name="fileName">The filename to use for the new zip archive.</param>
        /// <param name="statusMessageWriter">A TextWriter to use for writing
        /// verbose status messages.</param>
        /// <param name="encoding">The Encoding is used as the default alternate encoding for entries with
        /// filenames or comments that cannot be encoded with the IBM437 code page.</param>
        /// <returns>A new <see cref="IZipFile" /> instance.</returns>
        public IZipFile Create(string fileName, TextWriter statusMessageWriter, Encoding encoding)
        {
            return new ZipFile(fileName, statusMessageWriter, encoding);
        }
    }
}
