﻿namespace ExtSpec.Build
{
    using ExtSpec.Build.Wrappers;

    /// <summary>
    /// Provides ZIP related services.
    /// </summary>
    public class ZipProvider : BuildServiceBase, IZipProvider
    {
        private IZipFileFactory zipFileFactory;

        /// <summary>
        /// Initializes a new instance of the <see cref="ZipProvider" /> class.
        /// </summary>
        /// <param name="context">The build context.</param>
        /// <param name="zipFileFactory">The zip file wrapper factory.</param>
        public ZipProvider(IBuildContext context, IZipFileFactory zipFileFactory)
            : base(context)
        {
            this.zipFileFactory = zipFileFactory;
        }

        /// <summary>
        /// Zips the examples.
        /// </summary>
        public void ZipExamples()
        {
            using (var zip = this.zipFileFactory.Create())
            {
                zip.AddDirectory(this.Context.ExamplePath);
                zip.Save(this.Context.ExampleZipFilePath);
            }
        }

        /// <summary>
        /// Zips the output.
        /// </summary>
        public void ZipOutput()
        {
            using (var zip = this.zipFileFactory.Create())
            {
                zip.AddFile(this.Context.OutputFilePath, string.Empty);
                zip.AddFile(this.Context.TypeScriptDefinitionFilePath, string.Empty);
                zip.AddFile(this.Context.LicenseFilePath, string.Empty);
                zip.Save(this.Context.MainZipFilePath);
            }
        }
    }
}
