﻿namespace ExtSpec.Specifications.Build
{
    using System.Reflection;
    using ExtSpec.Build;
    using ExtSpec.Specifications.Expectations;
    using Xunit;

    public class BuildContextUnit
    {
        public abstract class BuildContextUnitBase : UnitBase<BuildContext>
        {
            public override BuildContext Construct()
            {
                return new BuildContext(Assembly.GetExecutingAssembly(), "ROOT PATH");
            }
        }

        public class Constructor : BuildContextUnitBase
        {
            [Fact]
            public void Should_set_name_to_assembly_name()
            {
                I.Expect(this.Instance.Name).ToEqual("ExtSpec.Specifications");
            }

            [Fact]
            public void Should_set_title_to_assembly_title()
            {
                I.Expect(this.Instance.Title).ToEqual("Ext Spec Specifications");
            }

            [Fact]
            public void Should_set_version_to_assembly_informational_version()
            {
                I.Expect(this.Instance.Version).ToEqual("1.2.3");
            }

            [Fact]
            public void Should_set_copyright_to_assembly_copyright()
            {
                I.Expect(this.Instance.Copyright).ToEqual("Copyright © Qube 2012");
            }

            [Fact]
            public void Should_set_root_path_to_root_path_parameter()
            {
                I.Expect(this.Instance.RootPath).ToEqual("ROOT PATH");
            }
        }

        public class FormatFileName : BuildContextUnitBase
        {
            [Fact]
            public void Should_inject_name_and_version_into_format_parameter()
            {
                var actual = this.Instance.FormatFileName("{0}+{1}");

                I.Expect(actual).ToEqual("ExtSpec.Specifications+1.2.3");
            }
        }
    }
}
