﻿namespace ExtSpec.Specifications.Build
{
    using ExtSpec.Build;
    using ExtSpec.Specifications.Expectations;
    using ExtSpec.Specifications.Helpers;
    using Xunit;

    public class BuildProviderIntegration
    {
        public class Create
        {
            public Create()
            {
                this.Actual = BuildProvider.Create(typeof(BuildProviderIntegration).Assembly, "ROOT PATH");
            }

            public IBuildProvider Actual { get; set; }

            [Fact]
            public void Should_return_build_provider()
            {
                I.Expect(this.Actual).Not.ToBeNull();
                I.Expect(this.Actual).ToBeOfType<BuildProvider>();
            }

            [Fact]
            public void Should_bind_file_system_provider()
            {
                var fileSystemProvider = ReflectionHelper.GetFieldValue(this.Actual, "fileSystemProvider");

                I.Expect(fileSystemProvider).Not.ToBeNull();
                I.Expect(fileSystemProvider).ToBeOfType<FileSystemProvider>();
            }

            [Fact]
            public void Should_bind_script_compiler()
            {
                var scriptCompiler = ReflectionHelper.GetFieldValue(this.Actual, "scriptCompiler");

                I.Expect(scriptCompiler).Not.ToBeNull();
                I.Expect(scriptCompiler).ToBeOfType<ScriptCompiler>();
            }

            [Fact]
            public void Should_bind_zip_provider()
            {
                var zipProvider = ReflectionHelper.GetFieldValue(this.Actual, "zipProvider");

                I.Expect(zipProvider).Not.ToBeNull();
                I.Expect(zipProvider).ToBeOfType<ZipProvider>();
            }
        }
    }
}
