﻿namespace ExtSpec.Specifications.Build
{
    using ExtSpec.Build;
    using Moq;
    using Xunit;

    public class BuildProviderUnit
    {
        public abstract class BuildProviderUnitBase : UnitBase<BuildProvider>
        {
            public BuildProviderUnitBase()
            {
                this.FileSystemProviderMock = this.AutoMocker.Mock<IFileSystemProvider>();
                this.ScriptCompilerMock = this.AutoMocker.Mock<IScriptCompiler>();
                this.ZipProviderMock = this.AutoMocker.Mock<IZipProvider>();
            }

            public Mock<IFileSystemProvider> FileSystemProviderMock { get; private set; }

            public Mock<IScriptCompiler> ScriptCompilerMock { get; private set; }

            public Mock<IZipProvider> ZipProviderMock { get; private set; }
        }

        public class Build : BuildProviderUnitBase
        {
            public Build()
            {
                this.Instance.Build();
            }

            [Fact]
            public void Should_reset_build_path()
            {
                this.FileSystemProviderMock.Verify(x => x.ResetBuildPath());
            }

            [Fact]
            public void Should_compile()
            {
                this.ScriptCompilerMock.Verify(x => x.Compile("Build.ts"));
            }

            [Fact]
            public void Should_post_process()
            {
                this.ScriptCompilerMock.Verify(x => x.PostProcess());
            }

            [Fact]
            public void Should_rebuild_example_libraries()
            {
                this.FileSystemProviderMock.Verify(x => x.RebuildExampleLibrary());
                this.FileSystemProviderMock.Verify(x => x.CopyOutputToExamples());
            }

            [Fact]
            public void Should_zip_examples_and_distribution()
            {
                this.ZipProviderMock.Verify(x => x.ZipExamples());
                this.ZipProviderMock.Verify(x => x.ZipOutput());
            }

            [Fact]
            public void Should_clean_up_build_path()
            {
                this.FileSystemProviderMock.Verify(x => x.CleanupBuildPath());
            }
        }
    }
}
