﻿namespace ExtSpec.Specifications.Build
{
    using ExtSpec.Build;
    using ExtSpec.Build.Wrappers;
    using Moq;
    using Xunit;

    public class ZipProviderUnit
    {
        public abstract class ZipProviderUnitBase : BuildServiceUnitBase<ZipProvider>
        {
            public ZipProviderUnitBase()
            {
                this.ZipFileFactoryMock = this.AutoMocker.Mock<IZipFileFactory>();
                this.ZipFileMock = new Mock<IZipFile>();

                this.ZipFileFactoryMock
                    .Setup(x => x.Create())
                    .Returns(this.ZipFileMock.Object);
            }

            public Mock<IZipFileFactory> ZipFileFactoryMock { get; set; }

            public Mock<IZipFile> ZipFileMock { get; set; }
        }

        public class ZipExamples : ZipProviderUnitBase
        {
            public ZipExamples()
            {
                this.Instance.ZipExamples();
            }

            [Fact]
            public void Should_add_examples_directory_to_zip_file()
            {
                this.ZipFileMock.Verify(x => x.AddDirectory("EXAMPLE PATH"));
            }

            [Fact]
            public void Should_save_zip_file_to_example_path()
            {
                this.ZipFileMock.Verify(x => x.Save(@"EXAMPLE PATH\FILE.ZIP"));
            }
        }

        public class ZipDistributable : ZipProviderUnitBase
        {
            public ZipDistributable()
            {
                this.Instance.ZipOutput();
            }

            [Fact]
            public void Should_add_license_file_to_zip()
            {
                this.ZipFileMock.Verify(x => x.AddFile(@"BUILD PATH\LICENSE.TXT", string.Empty));
            }

            [Fact]
            public void Should_save_zip_file_to_main_path()
            {
                this.ZipFileMock.Verify(x => x.Save(@"BUILD PATH\FILE.ZIP"));
            }
        }
    }
}
